@@ -29,13 +29,13 @@ def get_neff(wavelength, width, thickness, sw_angle=90):
     Parameters
     ----------
         wavelength:  float or ndarray
-            wavelength
+            wavelength (Valid for 1450nm-1650nm)
         width:    float or ndarray
-            width
-        thickness:    float or ndarray
-                thickness
+            width (Valid for 400nm-600nm)
+        thickness:    float or ndarray 
+            thickness (Valid for 180nm-240nm)
         sw_angle:    float or ndarray
-            sw_angle
+            sw_angle (Valid for 80-90 degrees)
 
     Returns
     ----------
@@ -64,13 +64,13 @@ def get_coeffs(wavelength, width, thickness, sw_angle):
     Parameters
     ----------
         wavelength:    float or ndarray
-            wavelength
+            wavelength (Valid for 1450nm-1650nm)
         width:    float or ndarray
-            width
+            width (Valid for 400nm-600nm)
         thickness:    float or ndarray
-            thickness
+            thickness (Valid for 180nm-240nm)
         sw_angle:    float or ndarray
-            sw_angle
+            sw_angle (Valid for 80-90 degrees)
 
     Returns
     ----------
@@ -117,7 +117,7 @@ def get_closed_ans(
             used in odd mode estimation in neff + ao exp(go * g)
         neff:    float or ndarray
             effective index of waveguide
-        wavelength:    float or ndarray
+        wavelength:    float or ndarray (Valid for 1450nm-1650nm)
             wavelength
         gap:    float or ndarray
             gap distance
@@ -171,7 +171,7 @@ def clean_inputs(inputs):
             inputs[i] = np.array([inputs[i]])
 
     # take largest size of numpy arrays, or set value (if it's not 0)
-    n = max([len(i) for i in inputs])
+    n = max(len(i) for i in inputs)
 
     # if it's smaller than largest, make array full of same value
     for i in range(len(inputs)):
@@ -198,11 +198,11 @@ class DC(ABC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, sw_angle=90):
@@ -247,7 +247,7 @@ class DC(ABC):
         Parameters
         ----------
         wavelength : float or ndarray
-            Wavelength
+            Wavelength (Valid for 1450nm-1650nm)
 
         Returns
         ----------
@@ -306,7 +306,7 @@ class DC(ABC):
         Parameters
         ----------
         wavelength:    float or ndarray
-            wavelengths to get sparams at
+            wavelengths to get sparams at (Valid for 1450nm-1650nm)
 
         Returns
         ----------
@@ -316,11 +316,7 @@ class DC(ABC):
             size (n,4,4) complex matrix of scattering parameters, in order of passed in wavelengths
         """
         # get number of points to evaluate at
-        if np.isscalar(wavelength):
-            n = 1
-        else:
-            n = len(wavelength)
-
+        n = 1 if np.isscalar(wavelength) else len(wavelength)
         # check to make sure the geometry isn't an array
         if len(self._clean_args(None)[0]) != 1:
             raise ValueError(
@@ -350,7 +346,7 @@ class DC(ABC):
         ports : 2-tuple
             Specifies the port coming in and coming out
         wavelength : float or ndarray
-            Wavelength(s) to predict at
+            Wavelength(s) to predict at (Valid for 1450nm-1650nm)
         extra_arc : float, optional
             Adds phase to compensate for waveguides getting to gap function. Defaults to 0.
         part : {"both", "mag", "ph"}, optional
@@ -408,11 +404,11 @@ class GapFuncSymmetric(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         gap : function
-            Gap function as one progresses along the waveguide
+            Gap function as one progresses along the waveguide (Must always be > 100nm)
         dgap : function
             Derivative of the gap function
         zmin : float
@@ -420,7 +416,7 @@ class GapFuncSymmetric(DC):
         zmax : float
             Where to end integration in the gap function
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, gap, dgap, zmin, zmax, sw_angle=90):
@@ -489,7 +485,7 @@ class GapFuncSymmetric(DC):
         mag = np.ones(n)
         phase = np.zeros(n)
         for i in range(n):
-            if part == "both" or part == "mag":
+            if part in ["both", "mag"]:
                 f_mag = lambda z: float(
                     ae[i] * np.exp(-ge[i] * self.gap(z))
                     + ao[i] * np.exp(-go[i] * self.gap(z))
@@ -497,7 +493,7 @@ class GapFuncSymmetric(DC):
                 mag[i] = trig(
                     np.pi * quad(f_mag, self.zmin, self.zmax)[0] / wavelength[i]
                 )
-            if part == "both" or part == "ph":
+            if part in ["both", "ph"]:
                 f_phase = lambda z: float(
                     ae[i] * np.exp(-ge[i] * self.gap(z))
                     - ao[i] * np.exp(-go[i] * self.gap(z))
@@ -544,12 +540,7 @@ class GapFuncSymmetric(DC):
             -scale * self.gap(x * (self.zmax - self.zmin) + self.zmin) / 2
             - sc_width / 2,
         )
-        # dparaTop    = lambda x: (sc_zmax-sc_zmin, scale*(self.zmax-self.zmin)*self.dgap(x*(self.zmax-self.zmin)+self.zmin)/2)
-        # dparaBottom = lambda x: (sc_zmax-sc_zmin, -scale*(self.zmax-self.zmin)*self.dgap(x*(self.zmax-self.zmin)+self.zmin)/2)
-
-        sbend = False
-        if sbend_h != 0 and sbend_v != 0:
-            sbend = True
+        sbend = sbend_h != 0 and sbend_v != 0
         sbendDown = lambda x: (sbend_h * x, -sbend_v / 2 * (1 - np.cos(np.pi * x)))
         sbendUp = lambda x: (sbend_h * x, sbend_v / 2 * (1 - np.cos(np.pi * x)))
         dsbendDown = lambda x: (sbend_h, -np.pi * sbend_v / 2 * np.sin(np.pi * x))
@@ -607,11 +598,11 @@ class GapFuncAntiSymmetric(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         gap : function
-            Gap function as one progresses along the waveguide
+            Gap function as one progresses along the waveguide (Must always be > 100nm)
         zmin : float
             Where to begin integration in the gap function
         zmax : float
@@ -619,7 +610,7 @@ class GapFuncAntiSymmetric(DC):
         arc1, arc2, arc3, arc4 : float
             Arclength from entrance of each port till minimum coupling point
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(
@@ -695,7 +686,7 @@ class GapFuncAntiSymmetric(DC):
         mag = np.ones(n)
         phase = np.zeros(n)
         for i in range(n):
-            if part == "both" or part == "mag":
+            if part in ["both", "mag"]:
                 f_mag = lambda z: float(
                     ae[i] * np.exp(-ge[i] * self.gap(z))
                     + ao[i] * np.exp(-go[i] * self.gap(z))
@@ -703,7 +694,7 @@ class GapFuncAntiSymmetric(DC):
                 mag[i] = trig(
                     np.pi * quad(f_mag, self.zmin, self.zmax)[0] / wavelength[i]
                 )
-            if part == "both" or part == "ph":
+            if part in ["both", "ph"]:
                 f_phase = lambda z: float(
                     ae[i] * np.exp(-ge[i] * self.gap(z))
                     - ao[i] * np.exp(-go[i] * self.gap(z))
@@ -741,15 +732,15 @@ class HalfRing(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         radius : float or ndarray
             Distance from center of ring to middle of waveguide in nm.
         gap : float or ndarray
-            Minimum distance from ring waveguide edge to straight waveguide edge in nm.
+            Minimum distance from ring waveguide edge to straight waveguide edge in nm. (Must be > 100nm)
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, radius, gap, sw_angle=90):
@@ -821,13 +812,10 @@ class HalfRing(DC):
         # determine z distance
         if 1 in ports and 3 in ports:
             z_dist = 2 * (radius + width / 2)
-        elif 1 in ports and 4 in ports:
+        elif 1 in ports and 4 in ports or (2 not in ports or 4 not in ports) and 2 in ports and 3 in ports:
             z_dist = np.pi * radius / 2 + radius + width / 2
         elif 2 in ports and 4 in ports:
             z_dist = np.pi * radius
-        elif 2 in ports and 3 in ports:
-            z_dist = np.pi * radius / 2 + radius + width / 2
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -917,17 +905,17 @@ class HalfRacetrack(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         radius : float or ndarray
             Distance from center of ring to middle of waveguide in nm.
         gap : float or ndarray
-            Minimum distance from ring waveguide edge to straight waveguide edge in nm.
+            Minimum distance from ring waveguide edge to straight waveguide edge in nm. (Must be > 100nm)
         length : float or ndarray
             Length of straight portion of ring waveguide in nm.
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, radius, gap, length, sw_angle=90):
@@ -1009,13 +997,10 @@ class HalfRacetrack(DC):
         # determine z distance
         if 1 in ports and 3 in ports:
             z_dist = 2 * (radius + width / 2) + length
-        elif 1 in ports and 4 in ports:
+        elif 1 in ports and 4 in ports or (2 not in ports or 4 not in ports) and 2 in ports and 3 in ports:
             z_dist = np.pi * radius / 2 + radius + width / 2 + length
         elif 2 in ports and 4 in ports:
             z_dist = np.pi * radius + length
-        elif 2 in ports and 3 in ports:
-            z_dist = np.pi * radius / 2 + radius + width / 2 + length
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -1108,15 +1093,15 @@ class StraightCoupler(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         gap : float or ndarray
-           Distance between the two waveguides edge in nm.
+           Distance between the two waveguides edge in nm. (Must be > 100nm)
         length : float or ndarray
             Length of both waveguides in nm.
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, gap, length, sw_angle=90):
@@ -1186,15 +1171,8 @@ class StraightCoupler(DC):
             offset = np.pi / 2
 
         # determine z distance
-        if 1 in ports and 3 in ports:
+        if 1 in ports and 3 in ports or 1 in ports and 4 in ports or 2 in ports and 4 in ports or 2 in ports and 3 in ports:
             z_dist = length
-        elif 1 in ports and 4 in ports:
-            z_dist = length
-        elif 2 in ports and 4 in ports:
-            z_dist = length
-        elif 2 in ports and 3 in ports:
-            z_dist = length
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -1227,10 +1205,7 @@ class StraightCoupler(DC):
         sc_gap = self.gap * scale
         sc_length = self.length * scale
 
-        # make parametric functions
-        sbend = False
-        if sbend_h != 0 and sbend_v != 0:
-            sbend = True
+        sbend = sbend_h != 0 and sbend_v != 0
         sbendDown = lambda x: (sbend_h * x, -sbend_v / 2 * (1 - np.cos(np.pi * x)))
         sbendUp = lambda x: (sbend_h * x, sbend_v / 2 * (1 - np.cos(np.pi * x)))
         dsbendDown = lambda x: (sbend_h, -np.pi * sbend_v / 2 * np.sin(np.pi * x))
@@ -1288,11 +1263,11 @@ class Standard(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         gap : float or ndarray
-           Minimum distance between the two waveguides edge in nm.
+           Minimum distance between the two waveguides edge in nm. (Must be > 100nm)
         length : float or ndarray
             Length of the straight portion of both waveguides in nm.
         H : float or ndarray
@@ -1300,7 +1275,7 @@ class Standard(DC):
         H : float or ndarray
             Vertical distance between end of coupler until straight portion in nm.
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, gap, length, H, V, sw_angle=90):
@@ -1388,15 +1363,8 @@ class Standard(DC):
         z_dist = length + 2 * np.sqrt(
             H ** 2 + (V * np.pi / 2) ** 2
         ) / np.pi * special.ellipeinc(np.pi, m)
-        if 1 in ports and 3 in ports:
+        if 1 in ports and 3 in ports or 1 in ports and 4 in ports or 2 in ports and 4 in ports or 2 in ports and 3 in ports:
             z_dist = z_dist
-        elif 1 in ports and 4 in ports:
-            z_dist = z_dist
-        elif 2 in ports and 4 in ports:
-            z_dist = z_dist
-        elif 2 in ports and 3 in ports:
-            z_dist = z_dist
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -1439,9 +1407,7 @@ class Standard(DC):
         dsbendDown = lambda x: (sc_H, -np.pi * sc_V / 2 * np.sin(np.pi * x))
         dsbendUp = lambda x: (sc_H, np.pi * sc_V / 2 * np.sin(np.pi * x))
 
-        sbend = False
-        if sbend_h != 0 and sbend_v != 0:
-            sbend = True
+        sbend = sbend_h != 0 and sbend_v != 0
         sbendDownExtra = lambda x: (sbend_h * x, -sbend_v / 2 * (1 - np.cos(np.pi * x)))
         sbendUpExtra = lambda x: (sbend_h * x, sbend_v / 2 * (1 - np.cos(np.pi * x)))
         dsbendDownExtra = lambda x: (sbend_h, -np.pi * sbend_v / 2 * np.sin(np.pi * x))
@@ -1511,15 +1477,15 @@ class DoubleHalfRing(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         radius : float or ndarray
             Distance from center of ring to middle of waveguide in nm.
         gap : float or ndarray
-            Minimum distance from ring waveguide edge to other ring waveguide edge in nm.
+            Minimum distance from ring waveguide edge to other ring waveguide edge in nm. (Must be > 100nm)
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, radius, gap, sw_angle=90):
@@ -1589,15 +1555,8 @@ class DoubleHalfRing(DC):
             offset = np.pi / 2
 
         # determine z distance
-        if 1 in ports and 3 in ports:
+        if 1 in ports and 3 in ports or 1 in ports and 4 in ports or 2 in ports and 4 in ports or 2 in ports and 3 in ports:
             z_dist = np.pi * radius
-        elif 1 in ports and 4 in ports:
-            z_dist = np.pi * radius
-        elif 2 in ports and 4 in ports:
-            z_dist = np.pi * radius
-        elif 2 in ports and 3 in ports:
-            z_dist = np.pi * radius
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -1649,16 +1608,16 @@ class AngledHalfRing(DC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         radius : float or ndarray
             Distance from center of ring to middle of waveguide in nm.
         gap : float or ndarray
-            Minimum distance from ring waveguide edge to straight waveguide edge in nm.
+            Minimum distance from ring waveguide edge to straight waveguide edge in nm.  (Must be > 100nm)
         theta : float or ndarray
             Angle that the straight waveguide is curved in radians (???).
-        sw_angle : float or ndarray, optional
+        sw_angle : float or ndarray, optional (Valid for 80-90 degrees)
     """
 
     def __init__(self, width, thickness, radius, gap, theta, sw_angle=90):
@@ -1740,13 +1699,10 @@ class AngledHalfRing(DC):
         # determine z distance
         if 1 in ports and 3 in ports:
             z_dist = np.pi * (radius + width + gap)
-        elif 1 in ports and 4 in ports:
+        elif 1 in ports and 4 in ports or (2 not in ports or 4 not in ports) and 2 in ports and 3 in ports:
             z_dist = np.pi * (radius + width + gap) / 2 + np.pi * radius / 2
         elif 2 in ports and 4 in ports:
             z_dist = np.pi * radius
-        elif 2 in ports and 3 in ports:
-            z_dist = np.pi * (radius + width + gap) / 2 + np.pi * radius / 2
-        # if it's coming to itself, or to adjacent port
         else:
             return np.zeros(len(wavelength))
 
@@ -1787,13 +1743,13 @@ class Waveguide(ABC):
     Parameters
     ----------
         width : float or ndarray
-            Width of the waveguide in nm
+            Width of the waveguide in nm (Valid for 400nm-600nm)
         thickness : float or ndarray
-            Thickness of waveguide in nm
+            Thickness of waveguide in nm (Valid for 180nm-240nm)
         length : float or ndarray
             Length of waveguide in nm.
         sw_angle : float or ndarray, optional
-            Sidewall angle of waveguide from horizontal in degrees. Defaults to 90.
+            Sidewall angle of waveguide from horizontal in degrees (Valid for 80-90 degrees). Defaults to 90.
     """
 
     def __init__(self, width, thickness, length, sw_angle=90):
@@ -1839,7 +1795,7 @@ class Waveguide(ABC):
         Parameters
         ----------
         wavelength : float or ndarray
-            Wavelength
+            Wavelength (Valid for 1450nm-1650nm)
 
         Returns
         ----------
@@ -1903,7 +1859,7 @@ class Waveguide(ABC):
         Parameters
         ----------
         wavelength:    float or ndarray
-            wavelengths to get sparams at
+            wavelengths to get sparams at (Valid for 1450nm-1650nm)
 
         Returns
         ----------
@@ -1911,11 +1867,7 @@ class Waveguide(ABC):
             size (2,2,n) complex matrix of scattering parameters
         """
         # get number of points to evaluate at
-        if np.isscalar(wavelength):
-            n = 1
-        else:
-            n = len(wavelength)
-
+        n = 1 if np.isscalar(wavelength) else len(wavelength)
         # check to make sure the geometry isn't an array
         if len(self._clean_args(None)[0]) != 1:
             raise ValueError(
@@ -1939,7 +1891,7 @@ class Waveguide(ABC):
         Parameters
         ----------
         wavelength : float or ndarray
-            Wavelength(s) to predict at
+            Wavelength(s) to predict at (Valid for 1450nm-1650nm)
 
         Returns
         ----------
